use core::num;

use maud::{html, PreEscaped};

use crate::{request::context::RequestContext, user::User};

use rocket::{
    http::{ContentType, Status},
    request::{self, FromRequest, Request},
};

pub fn htmx_link(
    url: &str,
    class: &str,
    onclick: &str,
    content: PreEscaped<String>,
) -> PreEscaped<String> {
    html!(
        a class=(class) onclick=(onclick) href=(url) hx-get=(url) hx-target="#main_content" hx-push-url="true" hx-swap="innerHTML" {
            (content);
        };
    )
}

pub fn script(script: &str) -> PreEscaped<String> {
    html!(
        script {
            (PreEscaped(script))
        };
    )
}

pub fn shell(content: PreEscaped<String>, title: &str, user: Option<User>) -> PreEscaped<String> {
    html! {
        html {
            head {
                title { (title) };
                script src="https://cdn.tailwindcss.com" {};
                script src="https://unpkg.com/htmx.org@2.0.3" integrity="sha384-0895/pl2MU10Hqc6jd4RvrthNlDiE9U1tWmX7WRESftEDRosgxNsQG/Ze9YMRzHq" crossorigin="anonymous" {};
                meta name="viewport" content="width=device-width, initial-scale=1.0";
            };
            body class="bg-black text-white" {
                header class="bg-gray-800 text-white shadow-md py-2" {
                    
                    div class="flex justify-between px-6" {

                        a href="/" class="flex items-center space-x-2" {
                            img src="/favicon" alt="Logo" class="w-10 h-10 rounded-md";
                            span class="font-semibold text-xl" { "WatchDogs" };
                        };

                        @if user.is_some() {
                            p { (user.unwrap().username) };
                        };

                        };

                    };
                };

                div id="main_content" {
                    (content)
                };
            };
    }
}

pub async fn render_page(
    htmx: RequestContext,
    content: PreEscaped<String>,
    title: &str,
    user: Option<User>,
) -> (Status, (ContentType, String)) {
    if !htmx.is_htmx {
        (
            Status::Ok,
            (ContentType::HTML, shell(content, title, user).into_string()),
        )
    } else {
        (Status::Ok, (ContentType::HTML, content.into_string()))
    }
}


